@@ -16,10 +16,15 @@ namespace KIMAP
 class AclJobBasePrivate : public JobPrivate
 {
 public:
-    AclJobBasePrivate(Session *session, const QString &name) : JobPrivate(session, name), rightList(Acl::None), modifier(AclJobBase::Change)
+    AclJobBasePrivate(Session *session, const QString &name)
+        : JobPrivate(session, name)
+        , rightList(Acl::None)
+        , modifier(AclJobBase::Change)
+    {
+    }
+    ~AclJobBasePrivate()
     {
     }
-    ~AclJobBasePrivate() { }
 
     void setIdentifier(const QByteArray &identifier);
     Q_REQUIRED_RESULT QByteArray identifier() const;
