@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Andras Mantia <amantia@kde.org>
+    SPDX-FileCopyrightText: 2009 Andras Mantia <amantia@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIMAP_SETMETADATAJOB_H
@@ -26,7 +13,6 @@
 
 namespace KIMAP
 {
-
 class Session;
 struct Response;
 class SetMetaDataJobPrivate;
@@ -179,9 +165,9 @@ public:
      * Possible error codes that may be returned by the server.
      */
     enum MetaDataError {
-        NoError = 0,  /**< Used to indicate that no errors have been received */
-        TooMany = 1,  /**< Cannot add a new metadata item, because the limit has already been reached */
-        TooBig = 2,   /**< A metadata value was too big (see maxAcceptedSize()) */
+        NoError = 0, /**< Used to indicate that no errors have been received */
+        TooMany = 1, /**< Cannot add a new metadata item, because the limit has already been reached */
+        TooBig = 2, /**< A metadata value was too big (see maxAcceptedSize()) */
         NoPrivate = 4 /**< The server does not support private metadata entries */
     };
 
@@ -208,7 +194,6 @@ public:
 protected:
     void doStart() override;
     void handleResponse(const Response &response) override;
-
 };
 
 }
